/*
 * Lancaster University
 * Computing Department
 * 
 * Created by Eduardo Figueiredo
 * Date: 22 Jul 2007
 * 
 */

package lancs.mobilemedia.core.ui.controller;

import javax.microedition.lcdui.Alert;
import javax.microedition.lcdui.AlertType;
import javax.microedition.lcdui.Command;
import javax.microedition.lcdui.Display;
import javax.microedition.rms.RecordStoreFullException;

import lancs.mobilemedia.core.ui.MainUIMidlet;
import lancs.mobilemedia.core.ui.datamodel.AlbumData;
import lancs.mobilemedia.core.ui.datamodel.MediaData;
import lancs.mobilemedia.core.ui.screens.AddMediaToAlbum;
import lancs.mobilemedia.core.ui.screens.AlbumListScreen;
import lancs.mobilemedia.core.ui.screens.CaptureVideoScreen;
import lancs.mobilemedia.core.ui.screens.PhotoViewScreen;
import lancs.mobilemedia.core.util.Constants;
import lancs.mobilemedia.lib.exceptions.ImageNotFoundException;
import lancs.mobilemedia.lib.exceptions.ImagePathNotValidException;
import lancs.mobilemedia.lib.exceptions.InvalidImageDataException;
import lancs.mobilemedia.lib.exceptions.PersistenceMechanismException;

/**
 * @author Eduardo Figueiredo
 */
public class PhotoViewController extends AbstractController {

	String imageName = "";

	/**
	 * @param midlet
	 * @param nextController
	 * @param albumData
	 * @param albumListScreen
	 * @param currentScreenName
	 */
	public PhotoViewController(MainUIMidlet midlet, AlbumData albumData,
			AlbumListScreen albumListScreen, String imageName) {
		super(midlet, albumData, albumListScreen);
		this.imageName = imageName;
	}

	private AddMediaToAlbum setupCopyToAlbum() {
		AddMediaToAlbum copyPhotoToAlbum = new AddMediaToAlbum(
				"Copy Photo to Album");
		copyPhotoToAlbum.setItemName(imageName);
		copyPhotoToAlbum.setLabePath("Copy to Album:");
		copyPhotoToAlbum.setCommandListener(this);
		return copyPhotoToAlbum;
	}
	
	private byte[] loadImage() {
		return null;
	}


	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * ubc.midp.MobileMedia.core.ui.controller.ControllerInterface#handleCommand
	 * (javax.microedition.lcdui.Command, javax.microedition.lcdui.Displayable)
	 */
	public boolean handleCommand(Command c) {
		String label = c.getLabel();
		System.out
				.println("<* PhotoViewController.handleCommand() *> " + label);

		/** Case: Copy photo to a different album */
		if (label.equals("Copy")) {
			AddMediaToAlbum copyPhotoToAlbum = setupCopyToAlbum();
			Display.getDisplay(midlet).setCurrent(copyPhotoToAlbum);

			return true;
		}

		/** Case: Save a copy in a new album */
		else if (label.equals("Save Item")) {
			try {
				MediaData imageData = null;
				byte[] imgByte = loadImage();
				if ((imgByte == null) || (imgByte.length == 0))
				{
					try {
						System.out
								.println("<* PhotoViewController.handleCommand() *> imageName: "
										+ imageName);
						imageData = getAlbumData().getMediaInfo(imageName);
					} catch (ImageNotFoundException e) {
						Alert alert = new Alert(
								"Error",
								"The selected photo was not found in the mobile device",
								null, AlertType.ERROR);
						Display.getDisplay(midlet).setCurrent(alert,
								Display.getDisplay(midlet).getCurrent());
					}
				}

				String photoname = ((AddMediaToAlbum) getCurrentScreen())
						.getItemName();
				String albumname = ((AddMediaToAlbum) getCurrentScreen())
						.getPath();

				System.out
						.println("<* PhotoViewController.handleCommand() *> photoname: "
								+ photoname + " | albumname: " + albumname);

				processImage(imgByte, imageData, photoname, albumname);
			} catch (InvalidImageDataException e) {
				Alert alert = null;
				if (e instanceof ImagePathNotValidException)
					alert = new Alert("Error", "The path is not valid", null,
							AlertType.ERROR);
				else
					alert = new Alert("Error",
							"The image file format is not valid", null,
							AlertType.ERROR);
				Display.getDisplay(midlet).setCurrent(alert,
						Display.getDisplay(midlet).getCurrent());
				return true;
				// alert.setTimeout(5000);
			} catch (PersistenceMechanismException e) {
				Alert alert = null;
				if (e.getCause() instanceof RecordStoreFullException)
					alert = new Alert("Error", "The mobile database is full",
							null, AlertType.ERROR);
				else
					alert = new Alert("Error",
							"The mobile database can not add a new photo",
							null, AlertType.ERROR);
				Display.getDisplay(midlet).setCurrent(alert,
						Display.getDisplay(midlet).getCurrent());
			}
			((AlbumListScreen) getAlbumListScreen())
					.repaintListAlbum(getAlbumData().getAlbumNames());
			setCurrentScreen(getAlbumListScreen());
			ScreenSingleton.getInstance().setCurrentScreenName(
					Constants.ALBUMLIST_SCREEN);
			return true;
		}
		
		else if ((label.equals("Cancel")) || (label.equals("Back"))) {
			((AlbumListScreen) getAlbumListScreen())
					.repaintListAlbum(getAlbumData().getAlbumNames());
			setCurrentScreen(getAlbumListScreen());
			ScreenSingleton.getInstance().setCurrentScreenName(
					Constants.ALBUMLIST_SCREEN);
			return true;
		}

		return false;
	}
	
	private void processImage(byte[] imgByte, MediaData imageData,
			String photoname, String albumname)
			throws InvalidImageDataException, PersistenceMechanismException {
	
		//nothing to do
	}



}
